%global _hardened_build 1
%bcond_without pam
%bcond_without sqlite
%bcond_without db
%bcond_without ldap
%bcond_without mysql
%bcond_without postgresql
%bcond_without systemd

Summary:        OpenSource server implementation of the Jabber protocols
Name:           jabberd
Version:        2.6.1
Release:    1%{?dist}
License:        GPLv2+
Source0:        https://github.com/jabberd2/jabberd2/releases/download/jabberd-%{version}/jabberd-%{version}.tar.xz
Source1:        README
Source2:        jabberd.init
Source3:        jabberd.sysconfig
Patch0:         jabberd-crypto-policy.patch
Patch1:         jabberd-fix-paths.patch
Patch2:         unbreak-autoreconf.patch
Patch3:         0001-configure.ac-adapt-to-openssl-1.1.patch
Patch4:         0002-authreg_ldapfull-adapt-to-openssl-1.1.patch
Patch5:         0003-sx-ssl.c-adapt-to-openssl-1.1.patch
Patch6:         0001-Fix-build-errors-with-MariaDB-10.2.patch
Patch7:         181e736dcbb19c828266d88837f4343510b4d20e.patch
Patch8:         jabberd-c99.patch
URL:            http://jabberd2.org/
BuildRequires:  openssl-devel libidn-devel expat-devel
BuildRequires:  perl-generators
BuildRequires:  cppunit-devel
%if %{with systemd}
BuildRequires:          systemd-units
Requires(post):         systemd-units systemd-sysv
Requires(preun):        systemd-units
Requires(postun):       systemd-units
%else
Requires(post):         openssl chkconfig /sbin/service
Requires(pre):          shadow-utils
Requires(preun):        chkconfig shadow-utils /sbin/service
Requires(postun):       chkconfig /sbin/service
%endif
%if %{with pam}
BuildRequires:  pam-devel
%endif
%if %{with sqlite}
BuildRequires:  sqlite-devel
%endif
%if %{with db}
BuildRequires:  libdb-devel
%endif
%if %{with ldap}
BuildRequires:  openldap-devel
%endif
%if %{with mysql}
BuildRequires:  mariadb-connector-c-devel
%endif
%if %{with postgresql}
BuildRequires:  libpq-devel
%endif
BuildRequires:          libgsasl-devel udns-devel
BuildRequires:          http-parser-devel
BuildRequires:          autoconf libtool
BuildRequires: make
Requires(post):         openssl
Requires(pre):          shadow-utils
Requires(preun):        shadow-utils

%description
The jabberd project aims to provide an open-source server implementation of
the Jabber protocols for instant messaging and XML routing. The goal of this
project is to provide a scalable, reliable, efficient and extensible server
that provides a complete set of features and is up to date with the latest
protocol revisions.

jabberd2 is the next generation of the jabberd server. It has been
rewritten from the ground up to be scalable, architecturally sound, and to
support the latest protocol extensions coming out of the JSF.

This package defaults to use pam and sqlite.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
autoreconf --verbose --force --install
%patch6 -p1

%build
export CFLAGS="%{optflags}"
%configure \
        --sysconfdir=%{_sysconfdir}/%{name} \
        --localstatedir=%{_var}/lib \
%if %{with pam}
        --enable-pam \
%else
        --disable-pam \
%endif
%if %{with db}
        --enable-db \
%else
        --disable-db \
%endif
%if %{with mysql}
        --enable-mysql \
        --with-extra-library-path=%{_libdir}/mariadb \
%else
        --disable-mysql \
%endif
%if %{with ldap}
        --enable-ldap \
%else
        --disable-ldap \
%endif
%if %{with postgresql}
        --enable-pgsql \
%else
        --disable-pgsql \
%endif
%if %{with sqlite}
        --enable-sqlite \
%else
        --disable-sqlite \
%endif
        --enable-fs --enable-anon --enable-pipe --enable-ssl \
        --enable-websocket \
        --enable-debug

make %{?_smp_mflags}


%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

sed -i "s|/usr/pkg/bin/perl|/usr/bin/env perl|" tools/*.pl

install -dpm 700 %{buildroot}/%{_var}/lib/%{name}/{log,pid,db}
install -dpm 755 %{buildroot}%{_sysconfdir}/pam.d/
install -Dpm 644 tools/pam_jabberd %{buildroot}%{_sysconfdir}/pam.d/%{name}

install -dpm 755 %{buildroot}%{_datadir}/%{name}/
install -dpm 755 %{buildroot}%{_datadir}/%{name}/
for i in `ls tools`; do
    if [ $i == "Makefile" -o $i == "Makefile.am" -o $i == "Makefile.in" \
        -o $i == "jabberd.in" -o $i == "jabberd.rc" -o $i == "pam_jabberd" ]; then
        continue;
    fi

    sed -i "s|\r||g" tools/$i
    install -pm 755 tools/$i %{buildroot}%{_datadir}/%{name}/
done

install -dpm 755 %{buildroot}%{_sysconfdir}/%{name}/

%if ! %{with systemd}
rm -frv %{buildroot}%{_prefix}/lib/systemd

install -Dpm 755 %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
install -Dpm 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

sed -i -e "s,__BINDIR__,%{_bindir},g" \
       -e "s,__ETCDIR__,%{_sysconfdir}/%{name}/,g" \
       -e "s,__PIDDIR__,%{_var}/lib/%{name}/pid,g" \
       -e "s,__SYSCONF__,%{_sysconfdir}/sysconfig,g" \
          %{buildroot}%{_initrddir}/%{name} \
          %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%endif

find %{buildroot} -name "*.la" -delete

rm -f %{buildroot}/etc/jabberd/*.conf
rm -f %{buildroot}/usr/etc/init/*.conf

sed -i -e ':a;N;$!ba' \
            -e 's,<module>mysql</module>,<module>pam</module>,g' \
            -e "s,register-enable='true'>,realm='' require-starttls='true' pemfile='/etc/%{name}/server.pem'>,g" \
                %{buildroot}%{_sysconfdir}/%{name}/c2s.xml

touch %{buildroot}%{_sysconfdir}/jabberd/server.pem

rm -f %{buildroot}%{_bindir}/jabberd

rm -f %{buildroot}%{_sysconfdir}/%{name}/jabberd.cfg*

cp %{SOURCE1} .



%pre
getent group jabber >/dev/null || groupadd -r jabber
getent passwd jabber >/dev/null || \
useradd -r -g jabber -d %{_var}/lib/%{name} -s /sbin/nologin \
        -c "Jabber Server" jabber
exit 0

%post
%if %{with systemd}
%systemd_post %{name}.service
if [ $1 -eq 1 ] ; then
        export NEWPASS=$( dd if=/dev/urandom bs=20 count=1 2>/dev/null \
                                | sha1sum | awk '{print $1}' )
        cd %{_sysconfdir}/%{name}
        %{__sed} -i -f- router-users.xml router.xml <<END
s,<secret>secret</secret>,<secret>$NEWPASS</secret>,g
END
        %{__sed} -i -f- *.xml <<END
s,<pass>secret</pass>,<pass>$NEWPASS</pass>,g
END

fi

cd %{_sysconfdir}/%{name}
if [ ! -s server.pem ]; then
 if [ -e %{_bindir}/make-dummy-cert ]; then
  %{___build_shell} %{_bindir}/make-dummy-cert
 else
  %{___build_shell} %{_sysconfdir}/pki/tls/certs/make-dummy-cert server.pem
 fi
 chown root.jabber server.pem
 chmod 640 server.pem
fi
%else
if [ "$1" -eq "1" ]; then
        /sbin/chkconfig --add %{name}
        export NEWPASS=$( dd if=/dev/urandom bs=20 count=1 2>/dev/null \
                                | sha1sum | awk '{print $1}' )
        cd %{_sysconfdir}/%{name}
        %{__sed} -i -f- router-users.xml router.xml <<END
s,<secret>secret</secret>,<secret>$NEWPASS</secret>,g
END
        %{__sed} -i -f- *.xml <<END
s,<pass>secret</pass>,<pass>$NEWPASS</pass>,g
END

fi

cd %{_sysconfdir}/%{name}
if [ ! -s server.pem ]; then
 %{___build_shell} %{_sysconfdir}/pki/tls/certs/make-dummy-cert server.pem
 chown root.jabber server.pem
 chmod 640 server.pem
fi
%endif

%preun
%if %{with systemd}
%systemd_preun %{name}.service
%else
if [ "$1" -eq "0" ]; then
        /sbin/service %{name} stop > /dev/null 2>&1
        /sbin/chkconfig --del %{name}
fi
%endif


%postun
%if %{with systemd}
%systemd_postun_with_restart %{name}.service

%triggerun -- jabberd < 2.2.14-3
/usr/bin/systemd-sysv-convert --save %{name} >/dev/null 2>&1 ||:

/bin/systemctl --no-reload enable %{name}.service >/dev/null 2>&1 ||:

/sbin/chkconfig --del %{name} >/dev/null 2>&1 || :
/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
%else
if [ "$1" -eq "1" ]; then
        /sbin/service %{name} condrestart > /dev/null 2>&1
fi
%endif


%files
%doc AUTHORS COPYING ChangeLog NEWS README TODO README
%{_mandir}/man8/*
%{_bindir}/*
%if %{with systemd}
%{_unitdir}/*
%else
%{_initrddir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%endif
%{_libdir}/%{name}/
%attr(750, jabber, jabber) %dir %{_sysconfdir}/%{name}
%attr(750, jabber, jabber) %dir %{_sysconfdir}/%{name}/templates
%config(noreplace) %{_sysconfdir}/%{name}/server.pem
%attr(640, jabber, jabber) %config(noreplace) %{_sysconfdir}/%{name}/*xml*
%attr(640, jabber, jabber) %config(noreplace) %{_sysconfdir}/%{name}/templates/*xml*
%dir %{_datadir}/%{name}/
%attr(644,root,root) %{_datadir}/%{name}/*
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%attr(700, jabber, jabber) %{_var}/lib/%{name}

%changelog
* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-1
- initial build
